<?php

/**
 * @file
 * @todo delete, and use lib instead.
 * The setting for Ultimenu.
 */

/**
 * Menu callback for 'admin/structure/ultimenu'.
function ultimenu_form() {
  $path = drupal_get_path('module', 'ultimenu');
  $theme_default = config('system.theme')->get('default');

  $form['ultimenu'] = array(
    '#type' => 'details',
    '#title' => t('Ultimenu settings'),
    '#description' => t('An Ultimenu <strong>block</strong> is based on a <strong>menu</strong>. Ultimenu <strong>regions</strong> are based on the <strong>menu items</strong>. The result is a block contains regions containing blocks, as opposed to: a region contains blocks.'),
  );

  $form['#attached']['css'][] = $path . '/css/ultimenu.admin.css';

  $menus = ultimenu_get_menus();
  $blocks = ultimenu_get_settings('blocks');
  $form['ultimenu']['blocks'] = array(
    '#type' => 'checkboxes',
    '#title' => t('Toggle Ultimenu blocks'),
    '#options' => ultimenu_get_menus(),
    '#default_value' => !empty($blocks) ? array_values((array) $blocks) : array(),
    '#description' => t('Check one to create an Ultimenu <strong>block</strong>. The block will be available at <a href="@block_admin">block admin</a>, or context admin. And the relevant regions based on its enabled menu items will be available below after saving. Ultimenu will only care for the first top level menus. If you are willing to use submenus, please use <A href="@menu_block">menu_block.module</a>, and embed them inside Ultimenu regions, or use regular dropdown method, instead.', array('@block_admin' => url('admin/structure/block'), '@menu_block' => '//drupal.org/project/menu_block')),
  );

  // All available Ultimenu regions.
  $ultimenu_regions = ultimenu_regions();
  $regions = ultimenu_get_settings('regions');
  $form['ultimenu']['regions'] = array(
    '#type' => 'checkboxes',
    '#title' => t('Toggle Ultimenu regions'),
    '#options' => $ultimenu_regions,
    '#default_value' => !empty($regions) ? array_values((array) $regions) : array(),
    '#description' => t('Check one to enable an Ultimenu <strong>region</strong>. The regions will be available at block/context admin.'),
  );

  // Compare settings against Ultimenu regions stored in theme .info.yml.
  if ($theme_regions = ultimenu_get_ultimenu_theme_info()) {
    foreach ($theme_regions as $key => $region) {
      $form['ultimenu']['regions'][$key]['#attributes']['class'][] = 'stored-in-theme';
      // Option disabled, but region stored in theme .info.yml, provide hint.
      if (empty($regions[$key])) {
        // Ultimenu region is stored in .info.yml, and force remove is enabled.
        if (ultimenu_remove_ultimenu_theme_info()) {
          $form['ultimenu']['regions'][$key]['#field_suffix'] = t('&#8592; Stored, but force removed');
        }
        // Ultimenu region is stored in .info.yml, and force remove is disabled.
        else {
          $form['ultimenu']['regions'][$key]['#attributes']['class'][] = 'error';
          $form['ultimenu']['regions'][$key]['#field_suffix'] = t('&#8592; Stored, but disabled?');
        }
      }
    }
  }

  $goodies = ultimenu_get_settings('goodies');
  // Menu title tooltip: http://webdesign.about.com/od/htmltags/a/aa101005.htm
  $form['ultimenu']['goodies'] = array(
    '#type' => 'checkboxes',
    '#title' => t('Toggle Ultimenu goodies'),
    '#default_value' => !empty($goodies) ? array_values((array) $goodies) : array(),
    '#options' => array(
      'menu-desc' => t('Render menu description'),
      'desc-top' => t('Menu description above menu title'),
      'title-class' => t('Add title class to menu item list'),
      'mlid-class' => t('Add mlid class to menu item list'),
      'counter-class' => t('Add menu counter class'),
      'no-tooltip' => t('Remove browser tooltip'),
      'ultimenu-mlid' => t('Use mlid, not title for Ultimenu region key'),
      'force-remove-region' => t('Force remove Ultimenu region stored in <strong>@theme_default.info.yml</strong>', array('@theme_default' => $theme_default)),
      // 'use-hoverintent' => t('Use hoverIntent'),
      // 'use-easing' => t('Use easing'),
    ),
    '#description' => t('You can force remove unwanted Ultimenu regions stored in <strong>@theme_default.info.yml</strong>. Otherwise theme .info.yml will always win, ignoring the region checkboxes above.',
      array('@theme_default' => $theme_default)),
    // If using hoverIntent, please install jquery_hoverintent.module, and its
    // library. If using easing, please select the following easing method.
  );

  $form['ultimenu']['skins'] = array(
    '#type' => 'textfield',
    '#title' => t('Path to custom Ultimenu skins library'),
    '#default_value' => ultimenu_get_settings('skins'),
    '#description' => t('The path to Ultimenu skins folder, e.g.: <strong>sites/all/skins/ultimenu</strong> containing CSS files that will be used as options for each Ultimenu block. Please be specific with <strong>ultimenu</strong> directory to limit the scan. Or place skins in your theme default: <strong>@theme_default/css/ultimenu</strong> for auto discovery.',
    array(
      '@theme_default' => drupal_get_path('theme', $theme_default),
    )),
    '#element_validate' => array('ultimenu_element_validate_skins'),
  );

  // Provide region definitions for copy/paste.
  if (!empty($regions)) {
    $regions_enabled = ultimenu_regions_enabled();
    $copies = array();
    foreach ($regions_enabled as $key => $region) {
      $copies[] = "$key: '$region'";
    }
    
    if ($copies) {
      $copies = "regions:\n  " . implode("\n  ", $copies);
      $form['ultimenu']['markups'] = array(
        '#type' => 'item',
        '#markup' => '<textarea class="getfocus" spellcheck="false">' . $copies . '</textarea>' . t("<ol><li>Optionally copy the provided regions into your <strong>@theme_default.info.yml</strong> to permanently store Ultimenu regions.</li><li>If a menu item is deleted or disabled, the related Ultimenu region is deleted.</li><li>Don't forget to clear cache whenever you update <strong>@theme_default</strong> file.</li><li>If you disable a region here, but stored in <strong> @theme_default</strong>, you can force remove <strong>@theme_default </strong> regions by checking <strong>Force remove Ultimenu region stored in @theme_default</strong> above. Otherwise <strong> @theme_default</strong> always wins ignoring the above settings.</li></ol>",
          array(
          '@theme_default' => $theme_default,
        )),
      );
    }
  }

  // $form['#submit'][] = 'ultimenu_form_submit';
  $form['submit'] = array(
    '#type' => 'submit',
    '#value' => t('Save'),
  );
  return $form;
  //  return system_config_form($form, $form_state);
  // By default, render the form using theme_system_config_form().
  // $form['#theme'] = 'system_config_form';  
  // return $form;
}
 */
 
/**
 * Validate skins directory.

function ultimenu_element_validate_skins($element, &$form_state, $form) {
  if (!empty($element['#value']) && !is_dir($element['#value'])) {
    form_set_error($element['#name'], t('<strong>@skins</strong> do not exists. Please create the directory first.', array('@skins' => $element['#value'])));
  }
} 
*/
 
/**
 * Submit handler for ultimenu_form().
function ultimenu_form_submit($form, &$form_state) {
  $data = array();
  $data['blocks']  = $form_state['values']['blocks'];
  $data['regions'] = $form_state['values']['regions'];
  $data['goodies'] = $form_state['values']['goodies'];
  $data['skins']   = $form_state['values']['skins'];

  // Do not litter the ultimenu.settings.yml.
  foreach ($data['regions'] as $key => $value) {
    if (empty($value)) {
      unset($data['regions'][$key]);
    }
  }
  foreach ($data['blocks'] as $key => $value) {
    if (empty($value)) {
      unset($data['blocks'][$key]);
    }
  }

  config('ultimenu.settings')
    ->set('blocks', $data['blocks'])
    ->set('regions', $data['regions'])
    ->set('goodies', $data['goodies'])
    ->set('skins', $data['skins'])
    ->save();

  drupal_static_reset('ultimenu_regions');
  drupal_static_reset('ultimenu_regions_enabled');

  // Rebuild theme registry to register new regions.
  module_invoke('system', 'theme_data');
  drupal_theme_rebuild();

  // Warn to clear cache if anything fails.
  drupal_set_message(t('Please make sure to <a href="@clear">clear the cache</a> if trouble to see the updated regions at block admin.', array('@clear' => url('admin/config/development/performance'))));
}
*/
